summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/lru_key_value.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/query/lru_key_value.h')
-rw-r--r--src/mongo/db/query/lru_key_value.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/db/query/lru_key_value.h b/src/mongo/db/query/lru_key_value.h
index 808e0584662..8215c029375 100644
--- a/src/mongo/db/query/lru_key_value.h
+++ b/src/mongo/db/query/lru_key_value.h
@@ -88,9 +88,9 @@ namespace mongo {
* kv-store is full prior to the add() operation.
*
* If an entry is evicted, it will be returned in
* an auto_ptr for the caller to use before disposing.
*/
- std::auto_ptr<V> add(const K& key, V* entry) {
+ std::unique_ptr<V> add(const K& key, V* entry) {
// If the key already exists, delete it first.
KVMapConstIt i = _kvMap.find(key);
if (i != _kvMap.end()) {
@@ -117,11 +117,11 @@ namespace mongo {
invariant(_currentSize == _maxSize);
// Pass ownership of evicted entry to caller.
// If caller chooses to ignore this auto_ptr,
// the evicted entry will be deleted automatically.
- return std::auto_ptr<V>(evictedEntry);
+ return std::unique_ptr<V>(evictedEntry);
}
- return std::auto_ptr<V>();
+ return std::unique_ptr<V>();
}
/**
@@ -88,9 +88,9 @@ namespace mongo {
*
* If an entry is evicted, it will be returned in
- * an auto_ptr for the caller to use before disposing.
+ * an unique_ptr for the caller to use before disposing.
*/
@@ -117,11 +117,11 @@ namespace mongo {
invariant(_currentSize == _maxSize);
// Pass ownership of evicted entry to caller.
- // If caller chooses to ignore this auto_ptr,
+ // If caller chooses to ignore this unique_ptr,
// the evicted entry will be deleted automatically.